checkNumeric: Function for checking whether a treedata object contains only...

Description Usage Arguments Value Examples

View source: R/check.R

Description

This function can be used to check if a treedata object contains numeric columns and, if desired, drop all non-numeric columns.

Usage

1
checkNumeric(tdObject, return.numeric = TRUE)

Arguments

tdObject

A "treedata" object

return.numeric

If TRUE, then a treedata object with all numeric columns will be returned; non-numeric columns will be removed.

Value

If return.numeric, then an object of class "treedata" with only numeric columns.

Examples

1

arborworkflows/aRbor documentation built on June 11, 2020, 7:44 p.m.