Description Usage Arguments Value Examples
This function can be used to check if a treedata object contains numeric columns and, if desired, drop all non-numeric columns.
1 | checkNumeric(tdObject, return.numeric = TRUE)
|
tdObject |
A " |
return.numeric |
If TRUE, then a treedata object with all numeric columns will be returned; non-numeric columns will be removed. |
If return.numeric, then an object of class "treedata" with only numeric columns.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.